octo.exceptions — Octo 0.2 documentation

### Navigation

- index
- modules |
- Octo 0.2 documentation »
- Module code »

# Source code for octo.exceptions

    class OctoException(Exception):
    	pass

    class NotStartedError(OctoException):
    	"""Raised when trying to call octo.stop before octo.start"""
    	pass

    class AlreadyStartedError(OctoException):
    	"""Raised when trying to call octo.start more than once"""
    	pass

### Navigation

- index
- modules |
- Octo 0.2 documentation »
- Module code »